.. _bokeh.application.handlers.server_lifecycle:

bokeh.application.handlers.server_lifecycle
-------------------------------------------

.. automodule:: bokeh.application.handlers.server_lifecycle
    :members:
